//
//  KKCellWithCheckbox.m
//  CellWithCheckbox
//
//  Created by Tasuku Maeda on 7/1/12.
//  Copyright (c) 2012 KinkumaDesign. All rights reserved.
//

#import "KKCellWithCheckbox.h"

@interface KKCellWithCheckbox()
- (void)checkboxTapped:(id)sender event:(id)event;
@end

@implementation KKCellWithCheckbox
@synthesize delegate = _delegate;

- (void)dealloc
{
    [_cellNameLabel release];
    [_checkedImage release];
    [_uncheckedImage release];
    [_checkboxButton release];
    [super dealloc];
}

- (id)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        _checkboxButton = [[UIButton buttonWithType:UIButtonTypeCustom] retain];
        NSString *checkedImgPath = [[NSBundle mainBundle] pathForResource:@"checkedmark" ofType:@"png"];
        NSString *uncheckedImgPath = [[NSBundle mainBundle] pathForResource:@"uncheckmark" ofType:@"png"];
        _checkedImage = [[UIImage alloc] initWithContentsOfFile:checkedImgPath];
        _uncheckedImage = [[UIImage alloc] initWithContentsOfFile:uncheckedImgPath];
        [_checkboxButton setImage:_uncheckedImage forState:UIControlStateNormal];
        _checkboxButton.frame = CGRectMake(0, 0, 44, 44);
        [_checkboxButton addTarget:self
                            action:@selector(checkboxTapped:event:)
                  forControlEvents:UIControlEventTouchUpInside];
        [self addSubview:_checkboxButton];

        _cellNameLabel = [[UILabel alloc] initWithFrame:CGRectMake(60, 11, 250, 20)];
        _cellNameLabel.font = [UIFont fontWithName:@"HelveticaNeue" size:16];
        [self addSubview:_cellNameLabel];
    }
    return self;
}

- (void)setCellName:(NSString *)aCellName
{
    _cellNameLabel.text = aCellName;
}

- (void)checkboxTapped:(id)sender event:(id)event
{
    NSSet *set = [event allTouches];
    UITouch *touch = [set anyObject];
    if (touch && [_delegate respondsToSelector:@selector(cell:checkboxTappedEvent:)]){
        [_delegate cell:self checkboxTappedEvent:touch];
    }
}

- (void)setCheckboxState:(BOOL)isCheck
{
    if(isCheck){
        [_checkboxButton setImage:_checkedImage forState:UIControlStateNormal];
    }else{
        [_checkboxButton setImage:_uncheckedImage forState:UIControlStateNormal];
    }
}

- (void)setSelected:(BOOL)selected animated:(BOOL)animated
{
    [super setSelected:selected animated:animated];
    if (selected){
        _cellNameLabel.textColor = [UIColor whiteColor];
    }else{
        _cellNameLabel.textColor = [UIColor blackColor];
    }
}

@end
